==> tuia-advert-center-api-2.2.59-sources.jar: cn/com/duiba/tuia/core/api/dto/req/qualification/ReqeQualificationDetail.java <==


package cn.com.duiba.tuia.core.api.dto.req.qualification;

import cn.com.duiba.tuia.core.api.dto.QueryDto;
import cn.com.duiba.tuia.core.api.dto.rsp.account.QualificationAuditDto;
import cn.com.duiba.tuia.core.api.dto.rsp.account.QualificationPackageDto;
import cn.com.duiba.tuia.core.api.dto.rsp.account.QualificationResourceDto;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.List;

@ApiModel
public class ReqeQualificationDetail extends QueryDto {

    private static final long serialVersionUID = -6941318473299188675L;

    @ApiModelProperty("广告主名称")
    private String companyName;
    @ApiModelProperty("一级代理商名称")
    private String oneAgentName;
    @ApiModelProperty("资质要求列表")
    private List<QualificationResourceDto> tradeList;
    @ApiModelProperty("资质列表")
    private List<QualificationAuditDto> qualificationList;
    @ApiModelProperty("资质包列表")
    private List<QualificationPackageDto> packageList;

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getOneAgentName() {
        return oneAgentName;
    }

    public void setOneAgentName(String oneAgentName) {
        this.oneAgentName = oneAgentName;
    }

    public List<QualificationResourceDto> getTradeList() {
        return tradeList;
    }

    public void setTradeList(List<QualificationResourceDto> tradeList) {
        this.tradeList = tradeList;
    }

    public List<QualificationAuditDto> getQualificationList() {
        return qualificationList;
    }

    public void setQualificationList(List<QualificationAuditDto> qualificationList) {
        this.qualificationList = qualificationList;
    }

    public List<QualificationPackageDto> getPackageList() {
        return packageList;
    }

    public void setPackageList(List<QualificationPackageDto> packageList) {
        this.packageList = packageList;
    }
}

==> tuia-advert-center-api-2.5.55-sources.jar: cn/com/duiba/tuia/core/api/dto/req/qualification/ReqeQualificationDetail.java <==


package cn.com.duiba.tuia.core.api.dto.req.qualification;

import cn.com.duiba.tuia.core.api.dto.QueryDto;
import cn.com.duiba.tuia.core.api.dto.rsp.account.QualificationAuditDto;
import cn.com.duiba.tuia.core.api.dto.rsp.account.QualificationPackageDto;
import cn.com.duiba.tuia.core.api.dto.rsp.account.QualificationResourceDto;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.List;

@ApiModel
public class ReqeQualificationDetail extends QueryDto {

    private static final long serialVersionUID = -6941318473299188675L;

    @ApiModelProperty("广告主名称")
    private String companyName;

    @ApiModelProperty("一级代理商名称")
    private String oneAgentName;

    @ApiModelProperty("二级代理商名称")
    private String twoAgentName;

    @ApiModelProperty("三级代理商名称")
    private String threeAgentName;

    @ApiModelProperty("四级代理商名称")
    private String fourAgentName;

    @ApiModelProperty("资质要求列表")
    private List<QualificationResourceDto> tradeList;

    @ApiModelProperty("资质列表")
    private List<QualificationAuditDto> qualificationList;

    @ApiModelProperty("资质包列表")
    private List<QualificationPackageDto> packageList;

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getOneAgentName() {
        return oneAgentName;
    }

    public void setOneAgentName(String oneAgentName) {
        this.oneAgentName = oneAgentName;
    }

    public List<QualificationResourceDto> getTradeList() {
        return tradeList;
    }

    public void setTradeList(List<QualificationResourceDto> tradeList) {
        this.tradeList = tradeList;
    }

    public List<QualificationAuditDto> getQualificationList() {
        return qualificationList;
    }

    public void setQualificationList(List<QualificationAuditDto> qualificationList) {
        this.qualificationList = qualificationList;
    }

    public List<QualificationPackageDto> getPackageList() {
        return packageList;
    }

    public void setPackageList(List<QualificationPackageDto> packageList) {
        this.packageList = packageList;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getTwoAgentName() {
        return twoAgentName;
    }

    public void setTwoAgentName(String twoAgentName) {
        this.twoAgentName = twoAgentName;
    }

    public String getThreeAgentName() {
        return threeAgentName;
    }

    public void setThreeAgentName(String threeAgentName) {
        this.threeAgentName = threeAgentName;
    }

    public String getFourAgentName() {
        return fourAgentName;
    }

    public void setFourAgentName(String fourAgentName) {
        this.fourAgentName = fourAgentName;
    }
}
